class DeviceInfo:

    def __init__(self, name: str, host: str, port: int, properties: dict):
        self.name = name
        self.host = host
        self.port = port
        self.properties = properties

    def __str__(self):
        return f"{self.name} ({self.host}:{self.port})"


class BtDeviceInfo:

    def __init__(self, name: str, address: str, rssi: int, is_likely_atv: bool):
        self.name = name
        self.address = address
        self.rssi = rssi
        self.is_likely_atv = is_likely_atv

    def __str__(self):
        tag = " [Android TV?]" if self.is_likely_atv else ""
        return f"{self.name} ({self.address}) RSSI: {self.rssi}{tag}"
